@@ -7,23 +7,39 @@
  * Copyright 2010, 2011 Novell, Inc.
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
-#include <stdlib.h> /* for malloc */
 #include "atspi-private.h"
+#include <stdlib.h> /* for malloc */
+
+/**
+ * AtspiTable:
+ *
+ * An interface used by containers whose data is arranged in a tabular form.
+ *
+ * An interface used by containers whose contained data is arranged
+ * in a tabular (i.e. row-column) form. Tables may resemble
+ * a two-dimensional grid, as in a spreadsheet, or may feature objects
+ * which span multiple rows and/or columns, but whose bounds are
+ * aligned on a row/column matrix. Objects within tables are children
+ * of the table object, and they may be referenced either via a child
+ * index or via a row/column pair. Table 'cells' may implement other
+ * interfaces, such as Text, Action, Image, and Component, and should do
+ * so as appropriate to their onscreen rresentation and/or behavior.
+ */
 
 /**
  * atspi_table_get_caption:
@@ -64,7 +80,7 @@ atspi_table_get_summary (AtspiTable *obj, GError **error)
 
   _atspi_dbus_get_property (obj, atspi_interface_table, "Summary", error, "(so)", &retval);
 
- return retval;
+  return retval;
 }
 
 /**
@@ -85,7 +101,7 @@ atspi_table_get_n_rows (AtspiTable *obj, GError **error)
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_get_property (obj, atspi_interface_table, "NRows", error, "i", &retval);
-	  
+
   return retval;
 }
 
@@ -107,7 +123,7 @@ atspi_table_get_n_columns (AtspiTable *obj, GError **error)
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_get_property (obj, atspi_interface_table, "NColumns", error, "i", &retval);
-	  
+
   return retval;
 }
 
@@ -118,7 +134,7 @@ atspi_table_get_n_columns (AtspiTable *obj, GError **error)
  * @column: the specified table column, zero-indexed.
  *
  * Gets the table cell at the specified row and column indices.
- * To get the accessible object at a particular (x, y) screen 
+ * To get the accessible object at a particular (x, y) screen
  * coordinate, use #atspi_component_get_accessible_at_point.
  *
  * Returns: (transfer full): an #AtspiAccessible object representing the
@@ -126,9 +142,9 @@ atspi_table_get_n_columns (AtspiTable *obj, GError **error)
  **/
 AtspiAccessible *
 atspi_table_get_accessible_at (AtspiTable *obj,
-                                 gint row,
-                                 gint column,
-                                 GError **error)
+                               gint row,
+                               gint column,
+                               GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
   DBusMessage *reply;
@@ -147,7 +163,7 @@ atspi_table_get_accessible_at (AtspiTable *obj,
  * @column: the specified table column, zero-indexed.
  *
  * Gets the 1-D child index corresponding to the specified 2-D row and
- * column indices. To get the accessible object at a particular (x, y) screen 
+ * column indices. To get the accessible object at a particular (x, y) screen
  * coordinate, use #atspi_component_get_accessible_at_point.
  *
  * @see #atspi_table_get_row_at_index, #atspi_table_get_column_at_index
@@ -157,9 +173,9 @@ atspi_table_get_accessible_at (AtspiTable *obj,
  **/
 gint
 atspi_table_get_index_at (AtspiTable *obj,
-                            gint row,
-                            gint column,
-                            GError **error)
+                          gint row,
+                          gint column,
+                          GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
   dbus_int32_t retval = -1;
@@ -167,7 +183,7 @@ atspi_table_get_index_at (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetIndexAt", error, "ii=>i", d_row, d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -176,7 +192,7 @@ atspi_table_get_index_at (AtspiTable *obj,
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
  * @index: the specified child index, zero-indexed.
  *
- * Gets the table row index occupied by the child at a particular 1-D 
+ * Gets the table row index occupied by the child at a particular 1-D
  * child index.
  *
  * @see #atspi_table_get_index_at, #atspi_table_get_column_at_index
@@ -186,8 +202,8 @@ atspi_table_get_index_at (AtspiTable *obj,
  **/
 gint
 atspi_table_get_row_at_index (AtspiTable *obj,
-                               gint index,
-                               GError **error)
+                              gint index,
+                              GError **error)
 {
   dbus_int32_t d_index = index;
   dbus_int32_t retval = -1;
@@ -195,7 +211,7 @@ atspi_table_get_row_at_index (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetRowAtIndex", error, "i=>i", d_index, &retval);
-	  
+
   return retval;
 }
 
@@ -214,8 +230,8 @@ atspi_table_get_row_at_index (AtspiTable *obj,
  **/
 gint
 atspi_table_get_column_at_index (AtspiTable *obj,
-                                  gint index,
-                                  GError **error)
+                                 gint index,
+                                 GError **error)
 {
   dbus_int32_t d_index = index;
   dbus_int32_t retval = -1;
@@ -223,7 +239,7 @@ atspi_table_get_column_at_index (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetColumnAtIndex", error, "i=>i", d_index, &retval);
-	  
+
   return retval;
 }
 
@@ -239,8 +255,8 @@ atspi_table_get_column_at_index (AtspiTable *obj,
  **/
 gchar *
 atspi_table_get_row_description (AtspiTable *obj,
-				   gint  row,
-				   GError **error)
+                                 gint row,
+                                 GError **error)
 {
   dbus_int32_t d_row = row;
   char *retval = NULL;
@@ -248,7 +264,7 @@ atspi_table_get_row_description (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, NULL);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetRowDescription", error, "i=>s", d_row, &retval);
-	  
+
   return retval;
 }
 
@@ -264,7 +280,8 @@ atspi_table_get_row_description (AtspiTable *obj,
  **/
 gchar *
 atspi_table_get_column_description (AtspiTable *obj,
-				      gint         column, GError **error)
+                                    gint column,
+                                    GError **error)
 {
   dbus_int32_t d_column = column;
   char *retval = NULL;
@@ -292,9 +309,9 @@ atspi_table_get_column_description (AtspiTable *obj,
  **/
 gint
 atspi_table_get_row_extent_at (AtspiTable *obj,
-                                gint         row,
-                                gint         column,
-                                GError **error)
+                               gint row,
+                               gint column,
+                               GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
   dbus_int32_t retval = -1;
@@ -302,7 +319,7 @@ atspi_table_get_row_extent_at (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetRowExtentAt", error, "ii=>i", d_row, d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -322,9 +339,9 @@ atspi_table_get_row_extent_at (AtspiTable *obj,
  **/
 gint
 atspi_table_get_column_extent_at (AtspiTable *obj,
-                                   gint         row,
-                                   gint         column,
-                                   GError **error)
+                                  gint row,
+                                  gint column,
+                                  GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
   dbus_int32_t retval = -1;
@@ -332,7 +349,7 @@ atspi_table_get_column_extent_at (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_call (obj, atspi_interface_table, "GetColumnExtentAt", error, "ii=>i", d_row, d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -349,8 +366,8 @@ atspi_table_get_column_extent_at (AtspiTable *obj,
  **/
 AtspiAccessible *
 atspi_table_get_row_header (AtspiTable *obj,
-			      gint         row,
-			      GError **error)
+                            gint row,
+                            GError **error)
 {
   dbus_int32_t d_row = row;
   DBusMessage *reply;
@@ -376,8 +393,8 @@ atspi_table_get_row_header (AtspiTable *obj,
  **/
 AtspiAccessible *
 atspi_table_get_column_header (AtspiTable *obj,
-				 gint column,
-				 GError **error)
+                               gint column,
+                               GError **error)
 {
   dbus_int32_t d_column = column;
   DBusMessage *reply;
@@ -393,7 +410,7 @@ atspi_table_get_column_header (AtspiTable *obj,
  * atspi_table_get_n_selected_rows:
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
  *
- * Query a table to find out how many rows are currently selected. 
+ * Query a table to find out how many rows are currently selected.
  * Not all tables support row selection.
  *
  * Returns: a #gint indicating the number of rows currently selected.
@@ -406,7 +423,7 @@ atspi_table_get_n_selected_rows (AtspiTable *obj, GError **error)
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_get_property (obj, atspi_interface_table, "NSelectedRows", error, "i", &retval);
-	  
+
   return retval;
 }
 
@@ -421,7 +438,7 @@ atspi_table_get_n_selected_rows (AtspiTable *obj, GError **error)
  **/
 GArray *
 atspi_table_get_selected_rows (AtspiTable *obj,
-                                 GError **error)
+                               GError **error)
 {
   GArray *rows = NULL;
 
@@ -444,7 +461,7 @@ atspi_table_get_selected_rows (AtspiTable *obj,
  **/
 GArray *
 atspi_table_get_selected_columns (AtspiTable *obj,
-                                 GError **error)
+                                  GError **error)
 {
   GArray *columns = NULL;
 
@@ -459,7 +476,7 @@ atspi_table_get_selected_columns (AtspiTable *obj,
  * atspi_table_get_n_selected_columns:
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
  *
- * Queries a table to find out how many columns are currently selected. 
+ * Queries a table to find out how many columns are currently selected.
  * Not all tables support column selection.
  *
  * Returns: a #gint indicating the number of columns currently selected.
@@ -472,7 +489,7 @@ atspi_table_get_n_selected_columns (AtspiTable *obj, GError **error)
   g_return_val_if_fail (obj != NULL, -1);
 
   _atspi_dbus_get_property (obj, atspi_interface_table, "NSelectedColumns", error, "i", &retval);
-	  
+
   return retval;
 }
 
@@ -481,15 +498,15 @@ atspi_table_get_n_selected_columns (AtspiTable *obj, GError **error)
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
  * @row: the zero-indexed row number of the row being queried.
  *
- * Determines whether a table row is selected.  Not all tables support 
+ * Determines whether a table row is selected.  Not all tables support
  * row selection.
  *
  * Returns: #TRUE if the specified row is currently selected, #FALSE if not.
  **/
 gboolean
 atspi_table_is_row_selected (AtspiTable *obj,
-                               gint row,
-                               GError **error)
+                             gint row,
+                             GError **error)
 {
   dbus_int32_t d_row = row;
   dbus_bool_t retval = FALSE;
@@ -513,8 +530,8 @@ atspi_table_is_row_selected (AtspiTable *obj,
  **/
 gboolean
 atspi_table_is_column_selected (AtspiTable *obj,
-                                  gint column,
-                                  GError **error)
+                                gint column,
+                                GError **error)
 {
   dbus_int32_t d_column = column;
   dbus_bool_t retval = FALSE;
@@ -522,7 +539,7 @@ atspi_table_is_column_selected (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "IsColumnSelected", error, "i=>b", d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -538,8 +555,8 @@ atspi_table_is_column_selected (AtspiTable *obj,
  **/
 gboolean
 atspi_table_add_row_selection (AtspiTable *obj,
-				 gint row,
-				 GError **error)
+                               gint row,
+                               GError **error)
 {
   dbus_int32_t d_row = row;
   dbus_bool_t retval = FALSE;
@@ -547,7 +564,7 @@ atspi_table_add_row_selection (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "AddRowSelection", error, "i=>b", d_row, &retval);
-	  
+
   return retval;
 }
 
@@ -563,8 +580,8 @@ atspi_table_add_row_selection (AtspiTable *obj,
  **/
 gboolean
 atspi_table_add_column_selection (AtspiTable *obj,
-				    gint column,
-				    GError **error)
+                                  gint column,
+                                  GError **error)
 {
   dbus_int32_t d_column = column;
   dbus_bool_t retval = FALSE;
@@ -572,7 +589,7 @@ atspi_table_add_column_selection (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "AddColumnSelection", error, "i=>b", d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -589,8 +606,8 @@ atspi_table_add_column_selection (AtspiTable *obj,
  **/
 gboolean
 atspi_table_remove_row_selection (AtspiTable *obj,
-				    gint row,
-				    GError **error)
+                                  gint row,
+                                  GError **error)
 {
   dbus_int32_t d_row = row;
   dbus_bool_t retval = FALSE;
@@ -598,7 +615,7 @@ atspi_table_remove_row_selection (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "RemoveRowSelection", error, "i=>b", d_row, &retval);
-	  
+
   return retval;
 }
 
@@ -616,8 +633,8 @@ atspi_table_remove_row_selection (AtspiTable *obj,
  **/
 gboolean
 atspi_table_remove_column_selection (AtspiTable *obj,
-				       gint column,
-				       GError **error)
+                                     gint column,
+                                     GError **error)
 {
   dbus_int32_t d_column = column;
   dbus_bool_t retval = FALSE;
@@ -625,20 +642,20 @@ atspi_table_remove_column_selection (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "RemoveColumnSelection", error, "i=>b", d_column, &retval);
-	  
+
   return retval;
 }
 
 /**
  * atspi_table_get_row_column_extents_at_index:
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
- * @index: the index of the #AtspiTable child whose row/column 
+ * @index: the index of the #AtspiTable child whose row/column
  * extents are requested.
  * @row: (out): back-filled with the first table row associated with
  * the cell with child index.
- * @col: (out): back-filled with the first table column associated 
+ * @col: (out): back-filled with the first table column associated
  * with the cell with child index.
- * @row_extents: (out): back-filled with the number of table rows 
+ * @row_extents: (out): back-filled with the number of table rows
  * across which child i extends.
  * @col_extents: (out): back-filled with the number of table columns
  * across which child i extends.
@@ -646,9 +663,9 @@ atspi_table_remove_column_selection (AtspiTable *obj,
  * if the child at index i corresponds to a selected table cell,
  * #FALSE otherwise.
  *
- * Given a child index, determines the row and column indices and 
+ * Given a child index, determines the row and column indices and
  * extents, and whether the cell is currently selected.  If
- * the child at index is not a cell (for instance, if it is 
+ * the child at index is not a cell (for instance, if it is
  * a summary, caption, etc.), #FALSE is returned.
  * The returned values are meaningful only if the Table has both
  * STATE_VISIBLE and STATE_SHOWING.
@@ -656,32 +673,36 @@ atspi_table_remove_column_selection (AtspiTable *obj,
  * Example:
  * If the #AtspiTable child at index '6' extends across columns 5 and 6 of
  * row 2 of an #AtspiTable instance, and is currently selected, then
- * 
+ *
  * retval = atspi_table_get_row_column_extents_at_index (table, 6,
- *                                             row, col, 
+ *                                             row, col,
  *                                             row_extents,
  *                                             col_extents,
  *                                             is_selected);
- * 
+ *
  * will return #TRUE, and after the call
  * row, col, row_extents, col_extents,
- * and is_selected will contain 2, 5, 1, 2, and 
+ * and is_selected will contain 2, 5, 1, 2, and
  * #TRUE, respectively.
  *
  * Returns: #TRUE if the index is associated with a valid table
- * cell, #FALSE if the index does not correspond to a cell.  If 
- * #FALSE is returned, the values of the out parameters are 
+ * cell, #FALSE if the index does not correspond to a cell.  If
+ * #FALSE is returned, the values of the out parameters are
  * undefined.
  **/
 gboolean
 atspi_table_get_row_column_extents_at_index (AtspiTable *obj,
-					    gint index, gint *row, gint *col, 
-					    gint *row_extents, gint *col_extents, 
-					    gboolean *is_selected, GError **error)
+                                             gint index,
+                                             gint *row,
+                                             gint *col,
+                                             gint *row_extents,
+                                             gint *col_extents,
+                                             gboolean *is_selected,
+                                             GError **error)
 {
   dbus_int32_t d_index = index;
   dbus_bool_t retval = FALSE;
-  dbus_int32_t d_row = 0,  d_col = 0, d_row_extents = 0, d_col_extents = 0;
+  dbus_int32_t d_row = 0, d_col = 0, d_row_extents = 0, d_col_extents = 0;
   dbus_bool_t d_is_selected = FALSE;
 
   g_return_val_if_fail (obj != NULL, FALSE);
@@ -692,14 +713,15 @@ atspi_table_get_row_column_extents_at_index (AtspiTable *obj,
 
   *row = d_row;
   *col = d_col;
-  *row_extents = d_row_extents;;
+  *row_extents = d_row_extents;
+  ;
   *col_extents = d_col_extents;
-  *is_selected = d_is_selected;;
-  
+  *is_selected = d_is_selected;
+  ;
+
   return retval;
 }
 
-
 /**
  * atspi_table_is_selected:
  * @obj: a pointer to the #AtspiTable implementor on which to operate.
@@ -712,9 +734,9 @@ atspi_table_get_row_column_extents_at_index (AtspiTable *obj,
  **/
 gboolean
 atspi_table_is_selected (AtspiTable *obj,
-                            gint row,
-                            gint column,
-                            GError **error)
+                         gint row,
+                         gint column,
+                         GError **error)
 {
   dbus_int32_t d_row = row, d_column = column;
   dbus_bool_t retval = FALSE;
@@ -722,7 +744,7 @@ atspi_table_is_selected (AtspiTable *obj,
   g_return_val_if_fail (obj != NULL, FALSE);
 
   _atspi_dbus_call (obj, atspi_interface_table, "IsSelected", error, "ii=>b", d_row, d_column, &retval);
-	  
+
   return retval;
 }
 
@@ -736,16 +758,15 @@ atspi_table_get_type (void)
 {
   static GType type = 0;
 
-  if (!type) {
-    static const GTypeInfo tinfo =
+  if (!type)
     {
-      sizeof (AtspiTable),
-      (GBaseInitFunc) atspi_table_base_init,
-      (GBaseFinalizeFunc) NULL,
-    };
+      static const GTypeInfo tinfo = {
+        sizeof (AtspiTable),
+        (GBaseInitFunc) atspi_table_base_init,
+        (GBaseFinalizeFunc) NULL,
+      };
 
-    type = g_type_register_static (G_TYPE_INTERFACE, "AtspiTable", &tinfo, 0);
-
-  }
+      type = g_type_register_static (G_TYPE_INTERFACE, "AtspiTable", &tinfo, 0);
+    }
   return type;
 }
